betty.gui.logging module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.logging module

Provide logging for the Graphical User Interface.

class betty.gui.logging.LogRecord

  Bases: `Text`

  Show a single log record.

  Parameters:

    record (`logging.LogRecord`)

  __init__(record: logging.LogRecord)
    Parameters:

      record (`logging.LogRecord`)

class betty.gui.logging.LogRecordViewer

  Bases: `QWidget`

  Show log records.

  __init__()
  log(record: logging.LogRecord) → None

    Add the log record to be shown.

    Parameters:

      record (`logging.LogRecord`)

    Return type:

      `None`

class betty.gui.logging.LogRecordViewerHandler

  Bases: `Handler`

  A logging handler that forwards all records to a `betty.gui.logging.LogRecordViewer`.

  Parameters:

    viewer (`betty.gui.logging.LogRecordViewer`)

  __init__(viewer: betty.gui.logging.LogRecordViewer)

    Initializes the instance - basically setting the formatter to None and the filter list to empty.

    Parameters:

      viewer (`betty.gui.logging.LogRecordViewer`)

  emit(record: logging.LogRecord) → None

    Do whatever it takes to actually log the specified logging record.

    This version is intended to be implemented by subclasses and so raises a NotImplementedError.

    Parameters:

      record (`logging.LogRecord`)

    Return type:

      `None`

  log

    pyqtSignal(*types, name: str = …, revision: int = …, arguments: Sequence = …) -> PYQT_SIGNAL

    types is normally a sequence of individual types. Each type is either a type object or a string that is the name of a C++ type. Alternatively each type could itself be a sequence of types each describing a different overloaded signal. name is the optional C++ name of the signal. If it is not specified then the name of the class attribute that is bound to the signal is used. revision is the optional revision of the signal that is exported to QML. If it is not specified then 0 is used. arguments is the optional sequence of the names of the signal’s arguments.